Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(313)

Unified Diff: third_party/WebKit/Source/platform/loader/fetch/FetchRequest.h

Issue 2676163002: Refactor the forPreload flag to mean speculative preload. (Closed)
Patch Set: Renamed ReportingPolicy and moved comments Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/loader/fetch/FetchRequest.h
diff --git a/third_party/WebKit/Source/platform/loader/fetch/FetchRequest.h b/third_party/WebKit/Source/platform/loader/fetch/FetchRequest.h
index a2dea7300360d84b156039c8629594a650be419d..44f7213d7b4d5339603f82ab68f80c49bafce83f 100644
--- a/third_party/WebKit/Source/platform/loader/fetch/FetchRequest.h
+++ b/third_party/WebKit/Source/platform/loader/fetch/FetchRequest.h
@@ -57,8 +57,8 @@ class PLATFORM_EXPORT FetchRequest {
};
// TODO(toyoshim): Consider to define an enum for preload options, and use it
// instead of bool in this class, FrameFetchContext, and so on. If it is
// reasonable, we try merging m_forPreload and m_linkPreload into one enum
// type. See https://crbug.com/675883.
struct ResourceWidth {
DISALLOW_NEW();
@@ -96,12 +96,12 @@ class PLATFORM_EXPORT FetchRequest {
return m_clientHintPreferences;
}
- bool forPreload() const { return m_forPreload; }
- void setForPreload(bool forPreload, double discoveryTime = 0);
+ bool isSpeculativePreload() const { return m_speculativePreload; }
+ void setSpeculativePreload(bool speculativePreload, double discoveryTime = 0);
double preloadDiscoveryTime() { return m_preloadDiscoveryTime; }
- bool isLinkPreload() { return m_linkPreload; }
+ bool isLinkPreload() const { return m_linkPreload; }
void setLinkPreload(bool isLinkPreload) { m_linkPreload = isLinkPreload; }
void setContentSecurityCheck(
@@ -152,7 +152,7 @@ class PLATFORM_EXPORT FetchRequest {
ResourceRequest m_resourceRequest;
String m_charset;
ResourceLoaderOptions m_options;
- bool m_forPreload;
+ bool m_speculativePreload;
bool m_linkPreload;
double m_preloadDiscoveryTime;
DeferOption m_defer;
@@ -57,8 +57,8 @@ class PLATFORM_EXPORT FetchRequest {
// TODO(toyoshim): Consider to define an enum for preload options, and use it
// instead of bool in this class, FrameFetchContext, and so on. If it is
- // reasonable, we try merging m_forPreload and m_linkPreload into one enum
- // type. See https://crbug.com/675883.
+ // reasonable, we try merging m_speculativePreload and m_linkPreload into one
+ // enum type. See https://crbug.com/675883.
struct ResourceWidth {
DISALLOW_NEW();

Powered by Google App Engine
This is Rietveld 408576698